@@ -1,13 +1,8 @@
-#!/usr/bin/env python
-# encoding: utf-8
-
+#!/usr/bin/env python3
 """
 a demo that shows how to call pymediainfo
 """
 
-from __future__ import (absolute_import, division,
-                        print_function, unicode_literals)
-
 import sys
 from pprint import pprint
 
@@ -25,19 +20,14 @@ def process(fname):
     for track in media_info.tracks:
         print_frame(track.track_type)
         pprint(track.to_data())
-    #
     print()
     for track in media_info.tracks:
         if track.track_type == 'General' and track.duration:
             print("Duration: {} sec.".format(track.duration / 1000.0))
 
-##############################################################################
 
 if __name__ == "__main__":
     if len(sys.argv) == 1:
         print("Usage: {} <media_file>".format(sys.argv[0]))
         sys.exit(0)
-    if sys.version_info.major < 3:
-        process(sys.argv[1].decode(sys.getfilesystemencoding()))
-    else:
-        process(sys.argv[1])
+    process(sys.argv[1])
